#!/usr/bin/env node
'use strict';

const path = require('path');

// Detect root path
global.appPath = path.dirname(require.main.filename);;

// Init Services Runner
const service = require('./services/moduleComposer');

// Start Server
function startServer(options){
  // Init MongoDB
  if(options && options.mongoose){
    require('./services/mongoose').init(options.mongoose);
  }

  // Run cluster
  require('./services/cluster').init();
}

// Start Module as a Service
function startService(serviceName, options){
  return service.start(serviceName, options);
}

// List available modules
function listServices(){
  return service.listExternalModules();
}

// Init Mongoose only
function initMongo(mongoose){
  require('./services/mongoose').init(mongoose);
}

module.exports = {
  server: startServer,
  service: startService,
  listServices: listServices,
  initMongo: initMongo
};
